Create a data source object for the Delphi Epidata API
Source:R/fetch_reporting_data.R
delphi_epidata_source.RdCreate a data source object for the Delphi Epidata API
R/fetch_reporting_data.R
delphi_epidata_source.RdCreate a data source object for the Delphi Epidata API