Skip to contents

Create a data source object for a forecast hub S3 bucket

Usage

hub_data_source(
  hub_name = "covid19-forecast-hub",
  target = "wk inc covid hosp"
)

Arguments

hub_name

Character, the S3 bucket name (e.g., "covid19-forecast-hub").

target

Character, the target name to filter to in the hub data (e.g., "wk inc covid hosp" for NHSN COVID hospitalizations).

Value

A source object of class "hub_data_source"