Fit a normal distribution with fixed mean to estimate variance
Source:R/fit_methods.R
fit_normal.RdTakes in a vector of observations and a vector of fixed means (predictions) and returns the maximum likelihood estimate of the variance. With a fixed mean, the MLE for variance is simply the mean squared error.
See also
Other estimate_observation_error:
fit_skellam()