Create a data source object for a forecast hub S3 bucket
Source:R/fetch_reporting_data_hubdata.R
hub_data_source.RdCreate a data source object for a forecast hub S3 bucket
R/fetch_reporting_data_hubdata.R
hub_data_source.RdCreate a data source object for a forecast hub S3 bucket